# Changelog

## v0.1.1 (2024-06-17)

### What's Changed
* change: get dimensions for aq.ArrayVar automatically by @Yash-10 in https://github.com/amazon-braket/autoqasm/pull/22
* fix: fix issue with kwargs while calling subroutine by @atharva-satpute in https://github.com/amazon-braket/autoqasm/pull/23
* fix: multi-dimensional ArrayVar declaration by @rmshaffer in https://github.com/amazon-braket/autoqasm/pull/25
* documentation: add .build() call on examples of displaying MainProgra… by @potatoboiler in https://github.com/amazon-braket/autoqasm/pull/24
* feat: Add @aq.hybrid_job decorator by @rmshaffer in https://github.com/amazon-braket/autoqasm/pull/21
* feature: support integer division by @abidart in https://github.com/amazon-braket/autoqasm/pull/29
* fix: mangle OpenQASM keywords by @atharva-satpute in https://github.com/amazon-braket/autoqasm/pull/28
* feature: add support for typecasting by @abidart in https://github.com/amazon-braket/autoqasm/pull/27
* fix: Pin amazon-braket-sdk version to 1.81.0 by @rmshaffer in https://github.com/amazon-braket/autoqasm/pull/35

### New Contributors
* @Yash-10 made their first contribution in https://github.com/amazon-braket/autoqasm/pull/22
* @atharva-satpute made their first contribution in https://github.com/amazon-braket/autoqasm/pull/23
* @potatoboiler made their first contribution in https://github.com/amazon-braket/autoqasm/pull/24
* @abidart made their first contribution in https://github.com/amazon-braket/autoqasm/pull/29

**Full Changelog**: https://github.com/amazon-braket/autoqasm/compare/v0.1.0...v0.1.1

## v0.1.0 (2024-05-22)

This is the initial pre-release version of AutoQASM.

AutoQASM is an experimental module offering a new quantum-imperative programming experience in Python for developing quantum programs.
